@@ -1,6 +1,6 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
-set -e -o pipefail
+. $(dirname "${BASH_SOURCE[0]}")/common.sh
 
 TMPDIR=$(mktemp -d $(basename $0).XXXXXX)
 
@@ -16,6 +16,4 @@ cd ${TMPDIR} && $DUB fetch --cache=local bloom &
 pid2=$!
 wait $pid1
 wait $pid2
-if [ ! -d ${TMPDIR}/bloom* ]; then
-    exit 1
-fi
+[ -d ${TMPDIR}/bloom* ]
